Struct eqlog_eqlog::ArgDeclListNode
source · pub struct ArgDeclListNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for ArgDeclListNode
impl Clone for ArgDeclListNode
sourcefn clone(&self) -> ArgDeclListNode
fn clone(&self) -> ArgDeclListNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ArgDeclListNode
impl Debug for ArgDeclListNode
sourceimpl Display for ArgDeclListNode
impl Display for ArgDeclListNode
sourceimpl From<u32> for ArgDeclListNode
impl From<u32> for ArgDeclListNode
sourceimpl Hash for ArgDeclListNode
impl Hash for ArgDeclListNode
sourceimpl Into<u32> for ArgDeclListNode
impl Into<u32> for ArgDeclListNode
sourceimpl Ord for ArgDeclListNode
impl Ord for ArgDeclListNode
sourcefn cmp(&self, other: &ArgDeclListNode) -> Ordering
fn cmp(&self, other: &ArgDeclListNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for ArgDeclListNode
impl PartialEq for ArgDeclListNode
sourcefn eq(&self, other: &ArgDeclListNode) -> bool
fn eq(&self, other: &ArgDeclListNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ArgDeclListNode
impl PartialOrd for ArgDeclListNode
sourcefn partial_cmp(&self, other: &ArgDeclListNode) -> Option<Ordering>
fn partial_cmp(&self, other: &ArgDeclListNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for ArgDeclListNode
impl Eq for ArgDeclListNode
impl StructuralEq for ArgDeclListNode
impl StructuralPartialEq for ArgDeclListNode