Struct eqlog_eqlog::DeclListNode
source · pub struct DeclListNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for DeclListNode
impl Clone for DeclListNode
sourcefn clone(&self) -> DeclListNode
fn clone(&self) -> DeclListNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for DeclListNode
impl Debug for DeclListNode
sourceimpl Display for DeclListNode
impl Display for DeclListNode
sourceimpl From<u32> for DeclListNode
impl From<u32> for DeclListNode
sourceimpl Hash for DeclListNode
impl Hash for DeclListNode
sourceimpl Into<u32> for DeclListNode
impl Into<u32> for DeclListNode
sourceimpl Ord for DeclListNode
impl Ord for DeclListNode
sourcefn cmp(&self, other: &DeclListNode) -> Ordering
fn cmp(&self, other: &DeclListNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for DeclListNode
impl PartialEq for DeclListNode
sourcefn eq(&self, other: &DeclListNode) -> bool
fn eq(&self, other: &DeclListNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for DeclListNode
impl PartialOrd for DeclListNode
sourcefn partial_cmp(&self, other: &DeclListNode) -> Option<Ordering>
fn partial_cmp(&self, other: &DeclListNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for DeclListNode
impl Eq for DeclListNode
impl StructuralEq for DeclListNode
impl StructuralPartialEq for DeclListNode