Struct eqlog_eqlog::PredDeclNode
source · pub struct PredDeclNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for PredDeclNode
impl Clone for PredDeclNode
sourcefn clone(&self) -> PredDeclNode
fn clone(&self) -> PredDeclNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PredDeclNode
impl Debug for PredDeclNode
sourceimpl Display for PredDeclNode
impl Display for PredDeclNode
sourceimpl From<u32> for PredDeclNode
impl From<u32> for PredDeclNode
sourceimpl Hash for PredDeclNode
impl Hash for PredDeclNode
sourceimpl Into<u32> for PredDeclNode
impl Into<u32> for PredDeclNode
sourceimpl Ord for PredDeclNode
impl Ord for PredDeclNode
sourcefn cmp(&self, other: &PredDeclNode) -> Ordering
fn cmp(&self, other: &PredDeclNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for PredDeclNode
impl PartialEq for PredDeclNode
sourcefn eq(&self, other: &PredDeclNode) -> bool
fn eq(&self, other: &PredDeclNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for PredDeclNode
impl PartialOrd for PredDeclNode
sourcefn partial_cmp(&self, other: &PredDeclNode) -> Option<Ordering>
fn partial_cmp(&self, other: &PredDeclNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for PredDeclNode
impl Eq for PredDeclNode
impl StructuralEq for PredDeclNode
impl StructuralPartialEq for PredDeclNode