Struct eqlog_eqlog::RuleDeclNode
source · pub struct RuleDeclNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for RuleDeclNode
impl Clone for RuleDeclNode
sourcefn clone(&self) -> RuleDeclNode
fn clone(&self) -> RuleDeclNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RuleDeclNode
impl Debug for RuleDeclNode
sourceimpl Display for RuleDeclNode
impl Display for RuleDeclNode
sourceimpl From<u32> for RuleDeclNode
impl From<u32> for RuleDeclNode
sourceimpl Hash for RuleDeclNode
impl Hash for RuleDeclNode
sourceimpl Into<u32> for RuleDeclNode
impl Into<u32> for RuleDeclNode
sourceimpl Ord for RuleDeclNode
impl Ord for RuleDeclNode
sourcefn cmp(&self, other: &RuleDeclNode) -> Ordering
fn cmp(&self, other: &RuleDeclNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for RuleDeclNode
impl PartialEq for RuleDeclNode
sourcefn eq(&self, other: &RuleDeclNode) -> bool
fn eq(&self, other: &RuleDeclNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for RuleDeclNode
impl PartialOrd for RuleDeclNode
sourcefn partial_cmp(&self, other: &RuleDeclNode) -> Option<Ordering>
fn partial_cmp(&self, other: &RuleDeclNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for RuleDeclNode
impl Eq for RuleDeclNode
impl StructuralEq for RuleDeclNode
impl StructuralPartialEq for RuleDeclNode