Struct eqlog_eqlog::StmtListNode
source · pub struct StmtListNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for StmtListNode
impl Clone for StmtListNode
sourcefn clone(&self) -> StmtListNode
fn clone(&self) -> StmtListNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for StmtListNode
impl Debug for StmtListNode
sourceimpl Display for StmtListNode
impl Display for StmtListNode
sourceimpl From<u32> for StmtListNode
impl From<u32> for StmtListNode
sourceimpl Hash for StmtListNode
impl Hash for StmtListNode
sourceimpl Into<u32> for StmtListNode
impl Into<u32> for StmtListNode
sourceimpl Ord for StmtListNode
impl Ord for StmtListNode
sourcefn cmp(&self, other: &StmtListNode) -> Ordering
fn cmp(&self, other: &StmtListNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for StmtListNode
impl PartialEq for StmtListNode
sourcefn eq(&self, other: &StmtListNode) -> bool
fn eq(&self, other: &StmtListNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for StmtListNode
impl PartialOrd for StmtListNode
sourcefn partial_cmp(&self, other: &StmtListNode) -> Option<Ordering>
fn partial_cmp(&self, other: &StmtListNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for StmtListNode
impl Eq for StmtListNode
impl StructuralEq for StmtListNode
impl StructuralPartialEq for StmtListNode