Struct eqlog_eqlog::TermListNode
source · pub struct TermListNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for TermListNode
impl Clone for TermListNode
sourcefn clone(&self) -> TermListNode
fn clone(&self) -> TermListNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TermListNode
impl Debug for TermListNode
sourceimpl Display for TermListNode
impl Display for TermListNode
sourceimpl From<u32> for TermListNode
impl From<u32> for TermListNode
sourceimpl Hash for TermListNode
impl Hash for TermListNode
sourceimpl Into<u32> for TermListNode
impl Into<u32> for TermListNode
sourceimpl Ord for TermListNode
impl Ord for TermListNode
sourcefn cmp(&self, other: &TermListNode) -> Ordering
fn cmp(&self, other: &TermListNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for TermListNode
impl PartialEq for TermListNode
sourcefn eq(&self, other: &TermListNode) -> bool
fn eq(&self, other: &TermListNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for TermListNode
impl PartialOrd for TermListNode
sourcefn partial_cmp(&self, other: &TermListNode) -> Option<Ordering>
fn partial_cmp(&self, other: &TermListNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for TermListNode
impl Eq for TermListNode
impl StructuralEq for TermListNode
impl StructuralPartialEq for TermListNode