Struct eqlog_eqlog::ThenAtomNode
source · pub struct ThenAtomNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for ThenAtomNode
impl Clone for ThenAtomNode
sourcefn clone(&self) -> ThenAtomNode
fn clone(&self) -> ThenAtomNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ThenAtomNode
impl Debug for ThenAtomNode
sourceimpl Display for ThenAtomNode
impl Display for ThenAtomNode
sourceimpl From<u32> for ThenAtomNode
impl From<u32> for ThenAtomNode
sourceimpl Hash for ThenAtomNode
impl Hash for ThenAtomNode
sourceimpl Into<u32> for ThenAtomNode
impl Into<u32> for ThenAtomNode
sourceimpl Ord for ThenAtomNode
impl Ord for ThenAtomNode
sourcefn cmp(&self, other: &ThenAtomNode) -> Ordering
fn cmp(&self, other: &ThenAtomNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for ThenAtomNode
impl PartialEq for ThenAtomNode
sourcefn eq(&self, other: &ThenAtomNode) -> bool
fn eq(&self, other: &ThenAtomNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ThenAtomNode
impl PartialOrd for ThenAtomNode
sourcefn partial_cmp(&self, other: &ThenAtomNode) -> Option<Ordering>
fn partial_cmp(&self, other: &ThenAtomNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for ThenAtomNode
impl Eq for ThenAtomNode
impl StructuralEq for ThenAtomNode
impl StructuralPartialEq for ThenAtomNode