Struct eqlog_eqlog::TypeDeclNode
source · pub struct TypeDeclNode(pub u32);Tuple Fields
0: u32Trait Implementations
sourceimpl Clone for TypeDeclNode
impl Clone for TypeDeclNode
sourcefn clone(&self) -> TypeDeclNode
fn clone(&self) -> TypeDeclNode
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TypeDeclNode
impl Debug for TypeDeclNode
sourceimpl Display for TypeDeclNode
impl Display for TypeDeclNode
sourceimpl From<u32> for TypeDeclNode
impl From<u32> for TypeDeclNode
sourceimpl Hash for TypeDeclNode
impl Hash for TypeDeclNode
sourceimpl Into<u32> for TypeDeclNode
impl Into<u32> for TypeDeclNode
sourceimpl Ord for TypeDeclNode
impl Ord for TypeDeclNode
sourcefn cmp(&self, other: &TypeDeclNode) -> Ordering
fn cmp(&self, other: &TypeDeclNode) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for TypeDeclNode
impl PartialEq for TypeDeclNode
sourcefn eq(&self, other: &TypeDeclNode) -> bool
fn eq(&self, other: &TypeDeclNode) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for TypeDeclNode
impl PartialOrd for TypeDeclNode
sourcefn partial_cmp(&self, other: &TypeDeclNode) -> Option<Ordering>
fn partial_cmp(&self, other: &TypeDeclNode) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for TypeDeclNode
impl Eq for TypeDeclNode
impl StructuralEq for TypeDeclNode
impl StructuralPartialEq for TypeDeclNode